@@ -5,6 +5,3 @@ from . import decorators
 from . import fixes
 from . import functions
 from . import models
-
-# noinspection PyProtectedMember
-from AthenaLib._info.info import info
